package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.LoadBalancerServicesMapper;
import com.zyc.system.domain.LoadBalancerServices;
import com.zyc.system.service.ILoadBalancerServicesService;

/**
 * 负载均衡服务Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class LoadBalancerServicesServiceImpl implements ILoadBalancerServicesService 
{
    @Autowired
    private LoadBalancerServicesMapper loadBalancerServicesMapper;

    /**
     * 查询负载均衡服务
     * 
     * @param id 负载均衡服务主键
     * @return 负载均衡服务
     */
    @Override
    public LoadBalancerServices selectLoadBalancerServicesById(Integer id)
    {
        return loadBalancerServicesMapper.selectLoadBalancerServicesById(id);
    }

    /**
     * 查询负载均衡服务列表
     * 
     * @param loadBalancerServices 负载均衡服务
     * @return 负载均衡服务
     */
    @Override
    public List<LoadBalancerServices> selectLoadBalancerServicesList(LoadBalancerServices loadBalancerServices)
    {
        return loadBalancerServicesMapper.selectLoadBalancerServicesList(loadBalancerServices);
    }

    /**
     * 新增负载均衡服务
     * 
     * @param loadBalancerServices 负载均衡服务
     * @return 结果
     */
    @Override
    public int insertLoadBalancerServices(LoadBalancerServices loadBalancerServices)
    {
        return loadBalancerServicesMapper.insertLoadBalancerServices(loadBalancerServices);
    }

    /**
     * 修改负载均衡服务
     * 
     * @param loadBalancerServices 负载均衡服务
     * @return 结果
     */
    @Override
    public int updateLoadBalancerServices(LoadBalancerServices loadBalancerServices)
    {
        return loadBalancerServicesMapper.updateLoadBalancerServices(loadBalancerServices);
    }

    /**
     * 批量删除负载均衡服务
     * 
     * @param ids 需要删除的负载均衡服务主键
     * @return 结果
     */
    @Override
    public int deleteLoadBalancerServicesByIds(Integer[] ids)
    {
        return loadBalancerServicesMapper.deleteLoadBalancerServicesByIds(ids);
    }

    /**
     * 删除负载均衡服务信息
     * 
     * @param id 负载均衡服务主键
     * @return 结果
     */
    @Override
    public int deleteLoadBalancerServicesById(Integer id)
    {
        return loadBalancerServicesMapper.deleteLoadBalancerServicesById(id);
    }
}
