package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.LoadBalancerServices;
import com.zyc.system.service.ILoadBalancerServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 负载均衡服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/LoadBalancerServicesController")
public class LoadBalancerServicesController extends BaseController
{
    @Autowired
    private ILoadBalancerServicesService loadBalancerServicesService;

    /**
     * 查询负载均衡服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(LoadBalancerServices loadBalancerServices)
    {
        startPage();
        List<LoadBalancerServices> list = loadBalancerServicesService.selectLoadBalancerServicesList(loadBalancerServices);
        return getDataTable(list);
    }

    /**
     * 导出负载均衡服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "负载均衡服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LoadBalancerServices loadBalancerServices)
    {
        List<LoadBalancerServices> list = loadBalancerServicesService.selectLoadBalancerServicesList(loadBalancerServices);
        ExcelUtil<LoadBalancerServices> util = new ExcelUtil<LoadBalancerServices>(LoadBalancerServices.class);
        util.exportExcel(response, list, "负载均衡服务数据");
    }

    /**
     * 获取负载均衡服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(loadBalancerServicesService.selectLoadBalancerServicesById(id));
    }

    /**
     * 新增负载均衡服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "负载均衡服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LoadBalancerServices loadBalancerServices)
    {
        return toAjax(loadBalancerServicesService.insertLoadBalancerServices(loadBalancerServices));
    }

    /**
     * 修改负载均衡服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "负载均衡服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LoadBalancerServices loadBalancerServices)
    {
        return toAjax(loadBalancerServicesService.updateLoadBalancerServices(loadBalancerServices));
    }

    /**
     * 删除负载均衡服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "负载均衡服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(loadBalancerServicesService.deleteLoadBalancerServicesByIds(ids));
    }
}
